@@ -5,7 +5,7 @@ import precis_i18n as precis
 
 
 def _escape(s):
-    return s.encode('unicode-escape').decode('ascii')
+    return s.encode("unicode-escape").decode("ascii")
 
 
 def _idempotent_ignoring_space(profile, value):
@@ -15,7 +15,7 @@ def _idempotent_ignoring_space(profile, value):
 
 
 results = Counter()
-profile = precis.get_profile('NicknameCaseMapped:ToLower')
+profile = precis.get_profile("NicknameCaseMapped:ToLower")
 
 for cp in range(0x0110000):
     char = chr(cp)
@@ -23,7 +23,7 @@ for cp in range(0x0110000):
         if not _idempotent_ignoring_space(profile, char):
             decomp = unicodedata.decomposition(char)
             kind = decomp.split()[0]
-            if kind.startswith('<'):
+            if kind.startswith("<"):
                 results[kind] += 1
             else:
                 print(_escape(char), unicodedata.name(char))
