@@ -2,11 +2,11 @@ import unicodedata
 
 from precis_i18n import get_profile
 
-profile = get_profile('nicknamecasemapped:ToLower')
+profile = get_profile("nicknamecasemapped:ToLower")
 
 
 def _escape(s):
-    return s.encode('unicode-escape').decode('ascii')
+    return s.encode("unicode-escape").decode("ascii")
 
 
 for cp in range(0x0110000):
@@ -16,7 +16,11 @@ for cp in range(0x0110000):
         if actual != original:
             idempotent = profile.enforce(actual)
             if idempotent.strip() != actual.strip():
-                print(_escape(original), unicodedata.name(original), ';',
-                      unicodedata.decomposition(original))
+                print(
+                    _escape(original),
+                    unicodedata.name(original),
+                    ";",
+                    unicodedata.decomposition(original),
+                )
     except UnicodeEncodeError:
         pass
